@@ -126,7 +126,7 @@ def final_df_checks_and_save_to_xls(
        completed)
     """
     # reorder the columns we added
-    if tracking_software == "DLC":
+    if tracking_software in ["DLC", "SLEAP"]:
         cols = [ID_COL, "Run", "Stepcycle", "Flipped", "Time"]
     elif tracking_software == "Universal 3D":
         cols = [ID_COL, "Leg", "Stepcycle", "Time"]
@@ -255,7 +255,7 @@ def import_and_combine_dfs(
     elif which_df == "X-Standardised":
         this_sheet_name = X_STANDARDISED_SHEET_NAME
     fullfilepath = os.path.join(group_dir, name, name + " - " + this_sheet_name)
-    if tracking_software == "DLC":
+    if tracking_software in ["DLC", "SLEAP"]:
         df = load_sheet_file(fullfilepath)
     elif tracking_software == "Universal 3D":
         df = load_sheet_file(fullfilepath, which_leg=which_leg)
@@ -277,7 +277,7 @@ def import_and_combine_dfs(
         # test: are our PCA & stats variables present in this ID's dataset?
         check_PCA_and_stats_variables(df_copy, group_name, name, folderinfo, cfg)
         # add some final info & append to group_df
-        if tracking_software == "DLC":
+        if tracking_software in ["DLC", "SLEAP"]:
             # add this run's info to df (& prepare Stepcycle column)
             # => I call DLC stuff ID NUM - RUN NUM, so we can use temp_split & idxing
             #    as done below
@@ -414,7 +414,7 @@ def avg_and_std(dfs, folderinfo, cfg):
     bin_num = cfg["bin_num"]
     save_to_xls = cfg["save_to_xls"]
     tracking_software = cfg["tracking_software"]
-    if tracking_software == "DLC":
+    if tracking_software in ["DLC", "SLEAP"]:
         analyse_average_x = cfg["analyse_average_x"]
     elif tracking_software == "Universal 3D":
         analyse_average_y = cfg["analyse_average_y"]
@@ -426,7 +426,7 @@ def avg_and_std(dfs, folderinfo, cfg):
     # loop over all groups' dfs
     for g, group_name in enumerate(group_names):
         # extract this df and IDs
-        if tracking_software == "DLC":
+        if tracking_software in ["DLC", "SLEAP"]:
             cols_to_exclude = [ID_COL, "Run", "Stepcycle", "Flipped", "Time"]
             for col in dfs[g].columns:
                 if col.endswith("likelihood"):
@@ -596,6 +596,7 @@ def grand_avg_and_std(avg_dfs, folderinfo, cfg):
 # %% .................  local functions #4 - load previous dataframes  .................
 def load_previous_runs_dataframes(folderinfo, cfg):
     """If user asked for it load previous runs dataframes instead of generating them (i.e., avg_dfs, g_avg_dfs, g_std_dfs)"""
+    load_dir = folderinfo["load_dir"]
     avg_dfs = [[]] * len(folderinfo["group_names"])
     g_avg_dfs = [[]] * len(folderinfo["group_names"])
     g_std_dfs = [[]] * len(folderinfo["group_names"])
@@ -623,7 +624,7 @@ def load_previous_runs_dataframes(folderinfo, cfg):
             error_msg = (
                 "\n******************\n! CRITICAL ERROR !\n******************\n"
                 + f"Unable to load the data of group '{group_name}' from \n"
-                + f"{folderinfo['load_dir']}"
+                + f"{load_dir}"
                 + "\n\nTry again!"
             )
             print(error_msg)
